# Copyright 2020 Google Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""List of dependencies for picatrix."""


DEPENDENCIES = [
    'altair>=4.1.0',
    'click>=7.1.2',
    'google-auth>=1.22.1',
    'google-auth-oauthlib>=0.4.1',
    'ipython>=7.18.1',
    'ipywidgets>=7.5.1',
    'jupyter>=1.0.0',
    'jupyter-http-over-ws>=0.0.8',
    'MarkupSafe>=1.1.1',
    'nest-asyncio>=1.4.1',
    'notebook>=6.1.4',
    'numpy>=1.19.2',
    'oauthlib==3.1.0',
    'pandas>=1.1.3',
    'python-dateutil>=2.8.1',
    'pytz>=2020.1',
    'PyYAML>=5.3.1',
    'requests>=2.24.0',
    'requests-oauthlib>=1.3.0',
    'timesketch-api-client>=20201027',
    'timesketch-import-client>=20200910',
    'vega>=3.4.0',
    'xlrd>=1.2.0',
]



#!/usr/bin/env python
# Copyright 2020 Google Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""This is the setup file for the project."""
from __future__ import unicode_literals

from setuptools import find_packages
from setuptools import setup

from picatrix import dependencies
from picatrix import version


long_description = (
    'picatrix - a framework to assist security analysts using '
    'Colab or Jupyter to perform forensic investigations.')

setup(
    name='picatrix',
    version=version.get_version(),
    description='Picatrix IPython Helpers',
    long_description=long_description,
    license='Apache License, Version 2.0',
    url='https://github.com/google/picatrix/',
    maintainer='Picatrix development team',
    maintainer_email='picatrix-developers@googlegroups.com',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=dependencies.DEPENDENCIES,
    test_require='test_requirements.txt',
)
